@@ -112,14 +112,18 @@ QAction* MainMenu::action(const QString &name) const
 
 void MainMenu::showAboutDialog()
 {
-    AboutDialog about(m_window);
-    about.exec();
+    AboutDialog* dialog = new AboutDialog(m_window);
+    dialog->open();
 }
 
 void MainMenu::showPreferences()
 {
-    Preferences* prefs = new Preferences(m_window, this);
-    prefs->show();
+    if (!m_preferences)
+        m_preferences = new Preferences(m_window, this);
+
+    m_preferences->show();
+    m_preferences->raise();
+    m_preferences->activateWindow();
 }
 
 void MainMenu::quitApplication()
@@ -316,7 +320,6 @@ void MainMenu::showDownloadManager()
 void MainMenu::showCookieManager()
 {
     CookieManager* m = new CookieManager(0);
-    m->setAttribute(Qt::WA_DeleteOnClose);
     m->show();
     m->raise();
 }
@@ -340,8 +343,8 @@ void MainMenu::showWebInspector()
 
 void MainMenu::showClearRecentHistoryDialog()
 {
-    ClearPrivateData clear(m_window);
-    clear.exec();
+    ClearPrivateData* dialog = new ClearPrivateData(m_window);
+    dialog->open();
 }
 
 void MainMenu::aboutQt()
@@ -629,12 +632,15 @@ void MainMenu::init()
     m_actions[QSL("Other/RestoreClosedTab")] = action;
 
 #ifdef Q_OS_MAC
-    m_actions[QSL("View/FullScreen")]->setShortcut(QKeySequence(QSL("F11")));
+    m_actions[QSL("View/FullScreen")]->setShortcut(QKeySequence(QSL("Ctrl+Meta+F")));
 
     // Add standard actions to File Menu (as it won't be ever cleared) and Mac menubar should move them to "Application" menu
     m_menuFile->addAction(m_actions[QSL("Standard/About")]);
     m_menuFile->addAction(m_actions[QSL("Standard/Preferences")]);
 
+    // Prevent ConfigInfo action to be detected as "Preferences..." action in Mac menubar
+    m_actions[QSL("Help/ConfigInfo")]->setMenuRole(QAction::NoRole);
+
     // Create Dock menu
     QMenu* dockMenu = new QMenu(0);
     dockMenu->addAction(m_actions[QSL("File/NewTab")]);
