@@ -17,7 +17,7 @@
 * ============================================================ */
 #include "qupzillaschemehandler.h"
 #include "qztools.h"
-#include "qupzilla.h"
+#include "browserwindow.h"
 #include "mainapplication.h"
 #include "tabbedwebview.h"
 #include "webpage.h"
@@ -25,6 +25,7 @@
 #include "pluginproxy.h"
 #include "plugininterface.h"
 #include "settings.h"
+#include "datapaths.h"
 #include "iconprovider.h"
 
 #include <QTextStream>
@@ -32,6 +33,12 @@
 #include <QSettings>
 #include <QWebSecurityOrigin>
 
+#if QT_VERSION < 0x050000
+#include "qwebkitversion.h"
+#else
+#include <QWebPage>
+#endif
+
 static QString authorString(const char* name, const QString &mail)
 {
     return QString("%1 &lt;<a href=\"mailto:%2\">%2</a>&gt;").arg(QString::fromUtf8(name), mail);
@@ -158,13 +165,15 @@ QString QupZillaSchemeReply::reportbugPage()
     bPage.replace(QLatin1String("%FIELDS-ARE-REQUIRED%"), tr("Please fill out all required fields!"));
 
     bPage.replace(QLatin1String("%INFO_OS%"), QzTools::operatingSystem());
-    bPage.replace(QLatin1String("%INFO_APP%"), QupZilla::VERSION
+    bPage.replace(QLatin1String("%INFO_APP%"),
 #ifdef GIT_REVISION
-                  + " (" + GIT_REVISION + ")"
+                  QString("%1 (%2)").arg(Qz::VERSION, GIT_REVISION)
+#else
+                  Qz::VERSION
 #endif
                  );
     bPage.replace(QLatin1String("%INFO_QT%"), QString("%1 (built with %2)").arg(qVersion(), QT_VERSION_STR));
-    bPage.replace(QLatin1String("%INFO_WEBKIT%"), QupZilla::WEBKITVERSION),
+    bPage.replace(QLatin1String("%INFO_WEBKIT%"), qWebKitVersion()),
                   bPage = QzTools::applyDirectionToPage(bPage);
 
     return bPage;
@@ -186,9 +195,9 @@ QString QupZillaSchemeReply::startPage()
     sPage.replace(QLatin1String("%TITLE%"), tr("Start Page"));
     sPage.replace(QLatin1String("%BUTTON-LABEL%"), tr("Search on Web"));
     sPage.replace(QLatin1String("%SEARCH-BY%"), tr("Search results provided by DuckDuckGo"));
-    sPage.replace(QLatin1String("%WWW%"), QupZilla::WIKIADDRESS);
+    sPage.replace(QLatin1String("%WWW%"), Qz::WIKIADDRESS);
     sPage.replace(QLatin1String("%ABOUT-QUPZILLA%"), tr("About QupZilla"));
-    sPage.replace(QLatin1String("%PRIVATE-BROWSING%"), mApp->isPrivateSession() ? tr("<h1>Private Browsing</h1>") : QString());
+    sPage.replace(QLatin1String("%PRIVATE-BROWSING%"), mApp->isPrivate() ? tr("<h1>Private Browsing</h1>") : QString());
     sPage = QzTools::applyDirectionToPage(sPage);
 
     return sPage;
@@ -211,14 +220,16 @@ QString QupZillaSchemeReply::aboutPage()
         aPage.replace(QLatin1String("%COPYRIGHT%"), tr("Copyright"));
 
         aPage.replace(QLatin1String("%VERSION-INFO%"),
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Version"), QupZilla::VERSION
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Version"),
 #ifdef GIT_REVISION
-                              + " (" + GIT_REVISION + ")"
+                              QString("%1 (%2)").arg(Qz::VERSION, GIT_REVISION)
+#else
+                              Qz::VERSION
 #endif
                                                           ) +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("WebKit version"), QupZilla::WEBKITVERSION));
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("WebKit version"), qWebKitVersion()));
         aPage.replace(QLatin1String("%MAIN-DEVELOPER%"), tr("Main developer"));
-        aPage.replace(QLatin1String("%MAIN-DEVELOPER-TEXT%"), authorString(QupZilla::AUTHOR.toUtf8(), "nowrep@gmail.com"));
+        aPage.replace(QLatin1String("%MAIN-DEVELOPER-TEXT%"), authorString(Qz::AUTHOR, "nowrep@gmail.com"));
         aPage.replace(QLatin1String("%CONTRIBUTORS%"), tr("Contributors"));
         aPage.replace(QLatin1String("%CONTRIBUTORS-TEXT%"),
                       authorString("Mladen Pejaković", "pejakm@autistici.org") + "<br/>" +
@@ -266,7 +277,8 @@ QString QupZillaSchemeReply::aboutPage()
                       authorString("Lasso Kante", "kantemou@gmail.com") + " (N'ko)<br/>" +
                       authorString("Kizito Birabwa", "kbirabwa@yahoo.co.uk") + " (Luganda)<br/>" +
                       authorString("Juan Carlos Sánchez", "hollow1984angel@gmail.com") + " (Mexican Spanish)<br/>" +
-                      authorString("Xabier Aramendi", "azpidatziak@gmail.com") + " (Basque)"
+                      authorString("Xabier Aramendi", "azpidatziak@gmail.com") + " (Basque)<br/>" +
+                      authorString("Ferhat AYDIN", "ferhataydin44@gmail.com") + " (Turkish)"
                      );
         aPage = QzTools::applyDirectionToPage(aPage);
     }
@@ -282,7 +294,6 @@ QString QupZillaSchemeReply::speeddialPage()
         dPage.append(QzTools::readAllFileContents(":html/speeddial.html"));
         dPage.replace(QLatin1String("%FAVICON%"), QLatin1String("qrc:icons/qupzilla.png"));
         dPage.replace(QLatin1String("%IMG_PLUS%"), QLatin1String("qrc:html/plus.png"));
-        dPage.replace(QLatin1String("%BOX-BORDER%"), QLatin1String("qrc:html/box-border-small.png"));
         dPage.replace(QLatin1String("%IMG_CLOSE%"), QLatin1String("qrc:html/close.png"));
         dPage.replace(QLatin1String("%IMG_EDIT%"), QLatin1String("qrc:html/edit.png"));
         dPage.replace(QLatin1String("%IMG_RELOAD%"), QLatin1String("qrc:html/reload.png"));
@@ -297,6 +308,7 @@ QString QupZillaSchemeReply::speeddialPage()
         dPage.replace(QLatin1String("%TITLE-REMOVE%"), tr("Remove"));
         dPage.replace(QLatin1String("%TITLE-RELOAD%"), tr("Reload"));
         dPage.replace(QLatin1String("%TITLE-WARN%"), tr("Are you sure to remove this speed dial?"));
+        dPage.replace(QLatin1String("%TITLE-WARN-REL%"), tr("Are you sure to reload all speed dials?"));
         dPage.replace(QLatin1String("%TITLE-FETCHTITLE%"), tr("Load title from page"));
         dPage.replace(QLatin1String("%URL%"), tr("Url"));
         dPage.replace(QLatin1String("%TITLE%"), tr("Title"));
@@ -339,9 +351,7 @@ QString QupZillaSchemeReply::restorePage()
         rPage.append(QzTools::readAllFileContents(":html/restore.html"));
         rPage.replace(QLatin1String("%FAVICON%"), QLatin1String("qrc:icons/qupzilla.png"));
         rPage.replace(QLatin1String("%BOX-BORDER%"), QLatin1String("qrc:html/box-border.png"));
-        rPage.replace(QLatin1String("%IMAGE%"), QzTools::pixmapToByteArray(qIconProvider->standardIcon(QStyle::SP_MessageBoxWarning).pixmap(45, 45)));
-
-
+        rPage.replace(QLatin1String("%IMAGE%"), QzTools::pixmapToByteArray(IconProvider::standardIcon(QStyle::SP_MessageBoxWarning).pixmap(45, 45)));
         rPage.replace(QLatin1String("%TITLE%"), tr("Restore Session"));
         rPage.replace(QLatin1String("%OOPS%"), tr("Oops, QupZilla crashed."));
         rPage.replace(QLatin1String("%APOLOGIZE%"), tr("We apologize for this. Would you like to restore the last saved state?"));
@@ -380,24 +390,26 @@ QString QupZillaSchemeReply::configPage()
         cPage.replace(QLatin1String("%PL-DESC%"), tr("Description"));
 
         cPage.replace(QLatin1String("%VERSION-INFO%"),
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Application version"), QupZilla::VERSION
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Application version"),
 #ifdef GIT_REVISION
-                              + " (" + GIT_REVISION + ")"
+                              QString("%1 (%2)").arg(Qz::VERSION, GIT_REVISION)
+#else
+                              Qz::VERSION
 #endif
                                                           ) +
                       QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Qt version"), QT_VERSION_STR) +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("WebKit version"), QupZilla::WEBKITVERSION) +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Build time"), QupZilla::BUILDTIME) +
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("WebKit version"), qWebKitVersion()) +
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Build time"), Qz::BUILDTIME) +
                       QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Platform"), QzTools::operatingSystem()));
 
         cPage.replace(QLatin1String("%PATHS-TEXT%"),
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Profile"), mApp->currentProfilePath()) +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Settings"), mApp->currentProfilePath() + "settings.ini") +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Saved session"), mApp->currentProfilePath() + "session.dat") +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Pinned tabs"), mApp->currentProfilePath() + "pinnedtabs.dat") +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Data"), mApp->DATADIR) +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Themes"), mApp->THEMESDIR) +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Translations"), mApp->TRANSLATIONSDIR));
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Profile"), DataPaths::currentProfilePath()) +
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Settings"), DataPaths::currentProfilePath() + "/settings.ini") +
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Saved session"), DataPaths::currentProfilePath() + "/session.dat") +
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Pinned tabs"), DataPaths::currentProfilePath() + "/pinnedtabs.dat") +
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Data"), DataPaths::path(DataPaths::AppData)) +
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Themes"), DataPaths::path(DataPaths::Themes)) +
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Translations"), DataPaths::path(DataPaths::Translations)));
 
 #ifdef QUPZILLA_DEBUG_BUILD
         QString debugBuild = tr("<b>Enabled</b>");
@@ -405,31 +417,21 @@ QString QupZillaSchemeReply::configPage()
         QString debugBuild = tr("Disabled");
 #endif
 
-#if defined (USE_WEBGL) || (QTWEBKIT_FROM_2_3 && defined(Q_OS_UNIX))
-        QString webGLEnabled = tr("<b>Enabled</b>");
-#else
-        QString webGLEnabled = tr("Disabled");
-#endif
-
+#ifdef Q_OS_WIN
 #if defined(Q_OS_WIN) && defined(W7API)
         QString w7APIEnabled = tr("<b>Enabled</b>");
 #else
         QString w7APIEnabled = tr("Disabled");
 #endif
-
-#if defined(Q_OS_UNIX) && defined(KDE_INTEGRATION)
-        QString KDEIntegration = tr("<b>Enabled</b>");
-#else
-        QString KDEIntegration = tr("Disabled");
 #endif
 
         QString portableBuild = mApp->isPortable() ? tr("<b>Enabled</b>") : tr("Disabled");
 
         cPage.replace(QLatin1String("%BUILD-CONFIG-TEXT%"),
                       QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Debug build"), debugBuild) +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("WebGL support"), webGLEnabled) +
+#ifdef Q_OS_WIN
                       QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Windows 7 API"), w7APIEnabled) +
-                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("KDE integration"), KDEIntegration) +
+#endif
                       QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Portable build"), portableBuild));
 
         cPage = QzTools::applyDirectionToPage(cPage);
